package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````"!8``#0```!HD0````0`!30`(``(
M`"@`%P`6``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!@````8````!`````$````!````````````````````C(D`
M`(R)```%`````!````$```#,C0``S)T``,R=``!X`@``I`(```8`````$```
M`@```-2-``#4G0``U)T``/````#P````!@````0````$````3`$``$P!``!,
M`0``)````"0````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9,R-``#,G0``S)T``#0"```T`@``!`````$````O;&EB+VQD
M+6UU<VPM87)M:&8N<V\N,0`$````%`````,```!'3E4`(0Q=X>TZ^I!A;BE;
M\7FY\:`UL.H1````3`````@````(`````9`0`"5`!(`H@!`%H(90A("!``(+
M(`2-.(`208H$"`A,````30```%$```!6````5P```%\```!@````80``````
M``!C````9`````````!E````9@```&D```````````````&O-.AJ?YI\ZM/O
M#L[>1RUOQ=\?+L6;MKB-\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MO
M0OK7A^)'Q@%8[Y=YF$_#F[OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_
MJ9R;X*<""FH:GE"_VE<;H^#[20``````````````````````````6!``````
M```#``@```````"@`````````P`2``$``````````````!(````)````````
M```````2````$```````````````$0```/8!`````````````!$```!_`0``
M```````````2````%P``````````````$@```,\!`````````````!(````?
M```````````````2````)@``````````````$@````,"`````````````!(`
M``#;`0`````````````2````+P``````````````(`````T#````````````
M`"$```!'```````````````2````30``````````````$@```%0`````````
M`````!(```#,`@`````````````2````X@(`````````````$@```%L`````
M`````````!(````>`@`````````````2````8@``````````````$@```*0"
M`````````````!(```!I```````````````2````<0``````````````$@``
M`,4"`````````````!(```!Y```````````````2````C0(`````````````
M$@```($``````````````!(```"*```````````````@````VP(`````````
M````$@```*8``````````````!(```"K```````````````2````G`$`````
M````````%@```*L"`````````````!(```!+`@`````````````2````M```
M````````````$@```#T"`````````````!(```!1`P`````````````2````
MM@(`````````````$0````P#`````````````!$```!O`@`````````````2
M````^0(`````````````$@````X#`````````````!$```"[````````````
M```2````Q```````````````$0```(T!`````````````!(```#6````````
M```````B````Y0``````````````(````/L``````````````!(```"L````
M```````````2````6P(`````````````$@`````!`````````````"````"8
M`@`````````````2````&@$`````````````$@```,`!`````````````!(`
M```?`0`````````````2````?0(`````````````$@```"4!````````````
M`!(```"O`0`````````````2````,P$`````````````$@```$0!````````
M`````!(````9`@`````````````2````*@(`````````````$@```$H!````
M`````````!(```!D`@`````````````2````U`(`````````````$@```/$"
M`````````````!(```!9`0`````````````2````%`(`````````````$@``
M`&`!`````````````!(```!G`0`````````````2````"P,`````````````
M(0```'@!`````````````!(```!9!```<*`````````0`!,`!@,``$`3``#(
M`@``$@`*`/`!``"81P``!````!(`"P"3`P``S"T``+`&```2``H`:00``(@W
M```\`0``$@`*`'`#``#D'P``!````!(`"@`-!```6!````0````2``@`M@,`
M`'PT```,`P``$@`*`!,$``!$H````````!``$P!!!```Z!\``*0"```2``H`
M[@,``$2@````````$``3`($#``"D+```*`$``!(`"@"@`P``'!X``%@````2
M``H`J`,``*PI``"@````$@`*`,P#``#`1```B`$``!(`"@#A`P``C"(``#``
M```2``H`^@,``'"@````````$``3``($``!,*@``<````!(`"@!D!```<*``
M```````0`!,`-@,``"P6``!H````$@`*`"$$``"\(@``K`$``!(`"@#7`P``
M0*````0````1`!(`.@0``$2@````````$``2`/,#```(%@```````!(`"@`*
M!```5$0``&P````2``H`/P,``(`L```D````$@`*`%H#``!T'@``<`$``!(`
M"@!.!```2$8``%`!```2``H`6`0``'"@````````$``3`"T$``!H)```1`4`
M`!(`"@``;W!E;F1I<@!M96UC;7``<W1D97)R`')E86QL;V,`86-C97-S`'-N
M<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S
M=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``<W1R<F-H<@!C
M;&]S961I<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!V9G!R
M:6YT9@!S=')C:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?
M9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I
M<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E
M<G)N;U]L;V-A=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!M96UC<'D`<W1R
M;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``<W1R8W!Y
M`')E861D:7(`<W1R=&]K`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!S<')I;G1F
M`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C
M+FUU<VPM87)M:&8N<V\N,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE
M8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY
M7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`7U]E;F1?7P!P87)?
M9&EE`'-H85]I;FET`%]?8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN
M:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N
M9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L
M+T-/4D4``,R=```7````T)T``!<```"\GP``%P```,B?```7````U)\``!<`
M````H```%P```!"@```7````%*```!<````<H```%P```""@```7````)*``
M`!<````HH```%P```"R@```7````-*```!<````XH```%P```$"@```7````
MP)\``!4%``#$GP``%08``,R?```5#@``T)\``!4?``#8GP``$R,``-R?```5
M*0``X)\``!4M``#DGP``%2\``.B?```5,0``[)\``!4R``#PGP``%38``/2?
M```5.P``^)\``!4]``#\GP``%4$``-">```6`P``U)X``!8$``#8G@``%@<`
M`-R>```6"```X)X``!8)``#DG@``%@H``.B>```6"P``[)X``!8,``#PG@``
M%@T``/2>```6#@``^)X``!80``#\G@``%A$```"?```6$@``!)\``!83```(
MGP``%A0```R?```6%0``$)\``!86```4GP``%A<``!B?```6&```')\``!89
M```@GP``%AH``"2?```6&P``*)\``!8<```LGP``%AT``#"?```6'@``-)\`
M`!8@```XGP``%B$``#R?```6(@``0)\``!8D``!$GP``%B4``$B?```6)@``
M3)\``!8G``!0GP``%B@``%2?```6*P``6)\``!8L``!<GP``%BX``&"?```6
M,```9)\``!8Q``!HGP``%C(``&R?```6,P``<)\``!8T``!TGP``%C4``'B?
M```6-P``?)\``!8X``"`GP``%CD``(2?```6.@``B)\``!8\``",GP``%CX`
M`)"?```6/P``E)\``!9```"8GP``%D(``)R?```60P``H)\``!9$``"DGP``
M%D4``*B?```61@``K)\``!9'``"PGP``%D@``+2?```620``N)\``!9+```!
M0"WI`4"]Z![_+^$$X"WE!."?Y0[@C^`(\+[E4(X```#&C^((RHSB4/Z\Y0#&
MC^((RHSB2/Z\Y0#&C^((RHSB0/Z\Y0#&C^((RHSB./Z\Y0#&C^((RHSB,/Z\
MY0#&C^((RHSB*/Z\Y0#&C^((RHSB(/Z\Y0#&C^((RHSB&/Z\Y0#&C^((RHSB
M$/Z\Y0#&C^((RHSB"/Z\Y0#&C^((RHSB`/Z\Y0#&C^((RHSB^/V\Y0#&C^((
MRHSB\/V\Y0#&C^((RHSBZ/V\Y0#&C^((RHSBX/V\Y0#&C^((RHSBV/V\Y0#&
MC^((RHSBT/V\Y0#&C^((RHSBR/V\Y0#&C^((RHSBP/V\Y0#&C^((RHSBN/V\
MY0#&C^((RHSBL/V\Y0#&C^((RHSBJ/V\Y0#&C^((RHSBH/V\Y0#&C^((RHSB
MF/V\Y0#&C^((RHSBD/V\Y0#&C^((RHSBB/V\Y0#&C^((RHSB@/V\Y0#&C^((
MRHSB>/V\Y0#&C^((RHSB</V\Y0#&C^((RHSB:/V\Y0#&C^((RHSB8/V\Y0#&
MC^((RHSB6/V\Y0#&C^((RHSB4/V\Y0#&C^((RHSB2/V\Y0#&C^((RHSB0/V\
MY0#&C^((RHSB./V\Y0#&C^((RHSB,/V\Y0#&C^((RHSB*/V\Y0#&C^((RHSB
M(/V\Y0#&C^((RHSB&/V\Y0#&C^((RHSB$/V\Y0#&C^((RHSB"/V\Y0#&C^((
MRHSB`/V\Y0#&C^((RHSB^/R\Y0#&C^((RHSB\/R\Y0#&C^((RHSBZ/R\Y0#&
MC^((RHSBX/R\Y0#&C^((RHSBV/R\Y0#&C^((RHSBT/R\Y0#&C^((RHSBR/R\
MY0#&C^((RHSBP/R\Y0#&C^((RHSBN/R\Y0#&C^((RHSBL/R\Y0#&C^((RHSB
MJ/R\Y0#&C^((RHSBH/R\Y0#&C^((RHSBF/R\Y0#&C^((RHSBD/R\Y0#&C^((
MRHSBB/R\Y0#&C^((RHSB@/R\Y0`````!RJ#C<$`MZ0S`3>#(#XSE6,*?Y2C0
M3>)4,I_E'`"-Y1@0C>44((WE#,"/X`,PG.<8$(WB%""-XAP`C>(T4I_E`#"3
MY20PC>4`,*#CI?__ZR0BG^4%4(_@`B"5YQPRG^4,((WE`S"5YP(0H.$#`*#A
M$#"-Y5G__^L$,I_E`S"5YP!`T^4``%3C3P``"G`O'>[P,9_E'`"=Y0,PG^<#
M0(#B`R"2YP0`@.+6,]+E!P%PXP,P@^/6,\+E8```B@`!H.&:___K`#"@X;PA
MG^48$)WE`B"/X`!@DN6PP9_EL%&?Y;#AG^4<()WE``"1Y0S`C^`%4(_@#N"/
MX`$`4N-A0(/H!#",Y50``-H$`$'B#,"#X@(!@.`$X+'E`0!0X03@K.7[__\:
M`\""X@#@H.-H49_E:!&?Y050C^`,`)7E!""@X0#@C>4!$(_@#.&#YS[__^L`
M`%#C*0``"D11G^4@8(WB!5"/X`P`E>55___K`$"@X3`!G^4&$*#A``"/X-4`
M`.L``%#C(```"APQG^4#,(_@#`"3Y8S__^OL_O_K#"&?Y<PPG^4"((_@`S"2
MYP`@D^4D,)WE`B`SX``PH.,J```:!`"@X2C0C>)P@+WH+?__Z]P@G^4``%#C
M`B"/X`P`@N4?```*5___ZW`O'>[$,)_E`S"?YP,PDN>N1L/EH___Z@P`E>5&
M___KTO__Z@@`E>4``%#C`0``"HH(`.O9___JE`"?Y080H.$``(_@J0``ZP``
M4.,(`(7ETO__"O7__^IX,)_E>`"?Y0,PE><``(_@`Q"@X0PPC>7._O_K!,"@
MX[#__^H!`*#C)___ZUS__^M4BP``(`$``"B+```X`0``-`$````!``#XBP``
M*(P``"R,```,-P``##<``.2+``#D"```N(L``"@T``",BP``V(D``$"+``"@
MB@``%#,``!@!``#P-````+"@XP#@H.,0$)_E`1"/X`T`H.$/P,#C#-"@X0``
M`.NXAP``!.`MY0#@H.,`(*#A1!"?Y40`G^4!$(_@``"1YQ303>(X,)_E"`"-
MY0,PD><PP)_E##"-Y03@C>4,$)'G`#"@X0`0C>4,`)WE!!"2Y.3^_^L4T(WB
M!/"=Y'R(```0`0``^`````0!```L`)_E+#"?Y0``C^`#,(_@``!3X2`PG^4#
M,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_AH(D``)R)```0B```#`$``#@`
MG^4X,)_E``"/X`,PC^``,$/@HQ^@X4,1@>`D,)_EP1"PX0,PC^`>_R\!&""?
MY0(PD^<``%/C'O\O`1/_+^%<B0``6(D``,"'```L`0```<J@XQ!`+>D,P$W@
M^`^,Y60PG^5D0)_E`S"/X``PT^4$0(_@``!3XQ"`O1A0,)_E`S"4YP``4^,"
M```*1#"?Y0,`G^>P_O_KQ___ZS@PG^4#,)3G``!3XP(```HL`)_E``"/X%3^
M_^L!(*#C(#"?Y0,PC^``(,/E$("]Z/R(``!TAP``)`$``)"(```(`0``^'$`
M`*2(``!`,)_E0""?Y0,PC^`",)/G``!3XPH```H!RJ#C$$`MZ0S`3>#X#XSE
M(!"?Y2``G^4!$(_@``"/X)#^_^L00+WHM/__ZK/__^KTA@``*`$``%"(``",
M<0```<J@X_!'+>D,P$W@X`^,Y<@PG^4`@%#B`S"/X"L```J\()_E`C"3YP"0
MD^4``%GC*```"@!0V.4!<*#A``!5XST`51,!4*`3`%"@`Q$``!H`0)GE``!4
MXPP```H)8*#A!2"@X0@0H.$$`*#A-_[_ZP``4.,"```:!3#4YST`4^,+```*
M!$"VY0``5./S__\:!`"@X?"'O>@(4*#A`3#UY0``4^,]`%,3^___&@A01>#F
M___J"6!&X`%0A>)&8:#A!4"$X`0`H.$`8(?E\(>]Z`A`H.'M___J"4"@X>O_
M_^J,A@``'`$```'*H.,00"WI#,!-X%@/C.6,()_EC#"?Y0(@C^"@T$WB`S"2
MYPT0H.$`,)/EG#"-Y0`PH.,`0*#A9/[_ZP``4.,``*`3!```&A`PG>4/.@/B
M"@I3XP$)4Q,*```*2""?Y4`PG^4"((_@`S"2YP`@D^6<,)WE`B`SX``PH.,'
M```:H-"-XA"`O>@"$*#C!`"@X<?]_^L0#V_AH`*@X>[__^I?_O_KI(4``"`!
M``!8A0```<J@X_!`+>D,P$W@2`^,Y50AG^54,9_E`B"/X`,PDN>DT$WB`%!0
MX@`PD^6<,(WE`#"@XP(```H`,-7E``!3XPH``!HH(9_E(#&?Y0(@C^`#,)+G
M`""3Y9PPG>4"(#/@`#"@XS\``!JDT(WB\("]Z)3]_^L`0%#B\?__"@0`H.&W
M_?_K``!0XR@```H3,-#E$V"`XBX`4^,"```:`3#6Y0``4^/T__\*$S#0Y2X`
M4^,C```*!0"@X2K^_^L`<*#A!@"@X2?^_^L``(?@`@"`XK+]_^L&,*#A`&"@
MX900G^4%(*#A`1"/X!7^_^L&`*#A#1"@X?W]_^L!`'#C!@"@X0,```H0,)WE
M#SH#X@$)4^,2```*GOW_ZP8`H.'\_?_K!`"@X8[]_^L``%#CUO__&@0`H.&K
M_?_K!0"@X>C]_^N____J`3#6Y2X`4^/8__\:`C#6Y0``4^/'__\*U/__ZJ;_
M_^OK___J`?[_Z_2$```@`0``P(0``)@M```!RJ#C\$<MZ0S`3>#8#XSE`4"@
MX1`BG^40,I_E`B"/X`,PDN<(T$WB`#"3Y00PC>4`,*#C`##1Y0!0H.$]`%/C
M`4"!`@0`H.'G_?_K#1"@X0!@H.$%`*#A(___Z]!QG^4`D%#B!W"/X$````K>
M_?_K``!6X3<``)JX,9_E`("=Y0-PE^<(@:#A`##5Y0``4^,]`%,3`3"@$P`P
MH`,%```*!3"@X0$@\^4``%+C/0!2$_O__QH%,$/@`@"&X@,`@.``8)?E5OW_
MZP``4.,(`(;G%0``"@4`H.$`,)?E"!"3YP$PT.0]`%/C``!3$P`PP>4&```*
M`2"!X@$PT.0"$*#A/0!3XP``4Q,!,,+D^?__&CTPH.,!(*#A`##!Y0$PU.0`
M`%/C`3#BY?O__QH((9_E^#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XS4`
M`!H(T(WB\(>]Z`&02>(!,-3D``!3XP$PZ>7[__\:[O__ZL`PG^4#<)?G`("7
MY0`PF.4``%/C)```"@@PH.$$(+/E"1"@X0``4N,!D(GB^O__&@,0@>(!$:#A
MD#"?Y0,PC^``()/E``!2XP\``!H!(*#C`0"@X0`@@^45_?_K`*!0XM7__PH(
M$*#A"8&@X0@@H.$2_?_K`*"'Y0`PH.,`D(WE`9")X@DQBN>B___J"`"@X=K\
M_^L``%#C`*"@X0``A^7%__\*"8&@X?+__^H#D*#A"!"@X]___^IR_?_K=(,`
M`"`!```L@P``'`$``%R"``"`@P```<J@XQ!`+>D,P$W@Z`^,Y7!/'>YL$)_E
M;#"?Y0$0C^`#,)'G$-!-XF``G^4,,(WE`R"@X0``G^=4,)_E5!"?Y0``E.<#
M,(_@`1"/X$;]_^L`P*#C0`"?Y4`PG^4``)_G/""?Y3P0G^4#,(_@``"4YP(@
MC^`($(WH`1"/X+;\_^L0T(WB$("]Z#"!```P`0``+((``"AK``!\*@``!((`
M`&`M``"4%@``:"H``#P0G^4\,)_E`1"/X`,PD>=PSQWN`R"@X0C03>(H`)_E
M!#"-Y0``G^<@,)_E(!"?Y0``G.<#,(_@`1"/X`C0C>(>_?_JF(```#`!``"0
M@0``C&H``.`I```!RJ#C<$`MZ0S`3>```(SE`<I,X@``C.4H``SE-"&?Y30Q
MG^4"VDWB&-!-X@(@C^`#,)+G`AJ-XA00@>(`,)/E`#"!Y0`PH..._/_K#,&?
MY0Q!G^4,(9_E#,"/X`Q@C>(`,*#A!!"@X08`H.$"((_@`,"-Y73\_^L!,(#B
M!`!3X3```(H!`'#C+P``"@%:C>(04(7B`2J@XP40H.$&`*#AP/S_ZP!`4.(G
M``"Z`0"$XHG\_^L`,%#B(P``"@4`4^$"```J!""#X`(`5>$=```Z!0!3X1@`
M`(J$()_E`@!4X1@``(H$(*#A`P"@X040H.'E_/_K`""@XP`PH.$$(,#G9!"?
MY5`@G^4!$(_@`@J-X@(@D><4`(#B`!"2Y0`@D.4!$#+@`""@XPD``!H#`*#A
M`MJ-XAC0C>)P@+WH!""%X`(`4^'C__\J\`#PYP`PH./J___JU?S_ZQR````@
M`0``J"D```$0``"(*0``0'\``*+__^H!RJ#C\$\MZ0S`3>```(SET``,Y5C"
MG^58(I_E0MU-XBS03>(,P(_@`%"@X4@"G^4"()SG0CV-X@APC>(!8*#A``"/
MX`<0H.$D,(/B`""2Y0`@@^4`(*#C]/W_ZR\0H.,`0*#A!0"@X6+\_^L``%#C
M$@``"@0"G^4%$*#A``"/X*_^_^L%`*#A]"&?Y>0QG^4"((_@0AV-X@,PDN<D
M$('B`""3Y0`PD>4"(#/@`#"@XVT``!I"W8WB+-"-XO"/O>@&`*#A//S_Z[@1
MG^4!$(_@BOS_ZP"@4.+E__\*`##:Y:2!G^6HD(WB``!3XPB`C^`$8$GB/P``
M"@``5.,$```*"A"@X00`H.$$_/_K``!0XR\```H*`*#AA/S_ZP$P0.(#,(K@
M`P!:X0`@H.$`L*#A`!"@,P`@BC`!,(HR`P``.@@``.H"`%/A`!#"Y0(```H!
MP'+E+P!<X_G__PH*`*#A<OS_ZP"PH.$%`*#A;_S_ZPL`@.`!`(#B`0I0X[S_
M_RH(P9_E"C"@X0S`C^`((*#A`1J@XP8`H.$$4(WE`,"-Y<S[_^L!`(#B`0I0
MXR\``(H'$*#A!@"@X3[\_^L``%#C`P``&I`P&>4/.@/B`@E3XQ4```JX$)_E
M``"@XP$0C^!&_/_K`*!0XJ'__PH`,-KE``!3X[___QH``%3C%@``"@`PU.4N
M`%/C`P``"H2@G^4!L*#C"J"/X-+__^H!,-3E``!3X^K__PKW___J`1"@XP8`
MH.&D^__K``!0X^3__QI4`)_E!A"@X0``C^`\_O_K!@"@X=C[_^N*___J/*"?
MY0&PH.,*H(_@OO__ZC+\_^OP`/#GL'X``"`!``!4*```)"@``$1^``#D)P``
MR"<``#0G``#4)@``?"8``%@F```L)@```<J@XQ!`+>D,P$W@^`^,Y2\0H.,`
M0*#AM?O_ZP``4.,!0(`2!`"@X1!`O>BY^__J`<J@XS!`+>D,P$W@``",Y1@`
M#.5T(9_E=#&?Y0':3>("((_@#-!-X@$:C>(#,)+G`%!0X@00@>(`,)/E`#"!
MY0`PH.,P```*`##5Y0``4^,M```*`/S_ZP$`@.(!"E#C.@``B@1`C>(%$*#A
M!`"@X9#[_^L$`*#A]_O_ZP$`0.(``(3@!`!0X0<``)H`(*#C`@``Z@0`4.$!
M(,#E`@``"@$P4.0O`%/C^?__"B\0H.,$`*#A@OO_ZP``4.,E```*!`!0X0`P
MH(,`,,"%!`"@X83[_^N\()_EM#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1
MY0(@,^``,*#C(@``&@':C>(,T(WB,("]Z(@@G^5\,)_E`B"/X`$:C>(#,)+G
M!!"!X@`@D^4`,)'E`B`SX``PH.,4```:8`"?Y0``C^`!VHWB#-"-XC!`O>AE
M^__J``"@X][__^I$()_E,#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@
M,^``,*#C(`"?!0``CP#L__\*M?O_Z^![```@`0``)'L``.QZ``"`)```H'H`
M`#@D```!RJ#C<$`MZ0S`3>#H#XSEQ"2?Y<0TG^4"((_@P%2?Y0,PDN>\9)_E
M"-!-X@50C^``,)/E!#"-Y0`PH.,&8(_@#4"@X000H.$&`*#AU_S_ZP``4.,.
M```*C#2?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKK___J5&2?Y09@C^`$$*#A!@"@X<'\_^L``%#C#@``
M"C0TG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E
M``!2XP0@@^3[__\:Z___Z@!DG^4&8(_@!!"@X08`H.&K_/_K``!0XPX```K<
M,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``
M4N,$((/D^___&NO__^JL8Y_E!F"/X`00H.$&`*#AE?S_ZP``4.,.```*A#.?
MY0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C
M!""#Y/O__QKK___J6&.?Y09@C^`$$*#A!@"@X7_\_^L``%#C#@``"BPSG^4`
M$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@
M@^3[__\:Z___Z@1CG^4&8(_@!!"@X08`H.%I_/_K``!0XPX```K4,I_E`!"=
MY0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D
M^___&NO__^JP8I_E!F"/X`00H.$&`*#A4_S_ZP``4.,.```*?#*?Y0`0G>4#
M,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O_
M_QKK___J7&*?Y09@C^`$$*#A!@"@X3W\_^L``%#C#@``"B0RG^4`$)WE`S"5
MYP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:
MZ___Z@ABG^4&8(_@!!"@X08`H.$G_/_K``!0XPX```K,,9_E`!"=Y0,PE><`
M()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO_
M_^JT89_E!F"/X`00H.$&`*#A$?S_ZP``4.,.```*=#&?Y0`0G>4#,)7G`""3
MY0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J
M8&&?Y09@C^`$$*#A!@"@X?O[_^L``%#C#@``"APQG^4`$)WE`S"5YP`@D^4!
M,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___Z@P!
MG^4$$*#A``"/X.;[_^L`$%#B`@``"O@`G^4``(_@IOS_Z_``G^4$$*#A``"/
MX-W[_^L`$%#B`@``"MP`G^4``(_@G?S_Z]0`G^4$$*#A``"/X-3[_^L`$%#B
M$@``"L``G^4``(_@E/S_Z[@@G^5D,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``
M,*#C$```&I@0G^68`)_E`1"/X```C^`(T(WB<$"]Z(3\_^J$`)_E!!"@X0``
MC^"[^__K`!!0XNG__PIP`)_E``"/X'O\_^OE___J=_K_ZSQZ```@`0``*'H`
M``0D```<`0``M",``&0C```8(P``R"(``(`B``#$(0``W"$``)`A``!$(0``
M<"```)P@``!P(```C"```(P@``"((```K!\``-QU``!D(```R!\``#0@``"X
M'P```<J@XP3@+>4,P$W@\`^,Y7@@G^5X,)_E`B"/X'0`G^4,T$WB`S"2YPT0
MH.$``(_@`#"3Y00PC>4`,*#CBOO_ZP``4.,%```*``#0Y0``4.,P`%`3`0"@
M`P``H!,!`"#B-""?Y2@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,!```:
M#-"-X@3PG>0Y^O_K^'0``"`!```4'P``J'0```'*H.,/`"WI!.`MY0S`3>#P
M#XSE1""?Y40PG^4"((_@`S"2YPS03>(`,)/E!#"-Y0`PH.,L,)_E+`"?Y10@
MC>(#,(_@`""-Y0`PD^<0$)WE``"3Y<7Y_^O_`*#CY_G_ZU1T```@`0``,'0`
M`/P`````P*#C\$<MZ0'HH.,,P$W@#N!,X`'*3.(``(SE#@!<X?O__QHX``[E
M`A"@XW3AG^5TP9_E`=A-XAC03>(.X(_@#,">YP%(C>(`(*#C`#"@XP#`G.44
MP(3E`,"@XP`0C>4`@*#A<OG_ZP%@4.(`<,'BQR^@X<<_)N`",%/@<S#_Y@(P
M(^`",%/@`B#"X`-@5N`"<,?@``!7XQ1`A.(W``"Z")&?Y0Q0C>(`$*#C!B"@
MX0<PH.$(`*#A`!"-Y5SY_^L!`''C`0!P`S(```H)(*#A!1"@X0@`H.&X^?_K
M`0!PXRD```H'`%#C'P``F@@`0.(`0)7@'```*K2@G^4*H(_@`@``Z@%`1.(%
M`%3A%@``.@@@H.,*$*#A!`"@X2GY_^L``%#C]O__&@5`1.`&`)3@Q!^GX'P@
MG^5L,)_E`B"/X`'(C>(#,)+G%,",X@`@D^4`,)SE`B`SX``PH.,0```:`=B-
MXAC0C>+PA[WH`6A6X@!PQ^(!`'?C`0AV`\G__QH``.#C`!"@X>G__^HH`)_E
M``"/X'W__^L@`)_E``"/X'K__^NO^?_KQ',``"`!```(``$`1'0``,1R```P
M'0``%!T```'*H.,00"WI#,!-X/@/C.6F^?_K5_G_ZP``4.,``)`5$("]Z`'*
MH./P0"WI#,!-X-@/C.7P()_E\&"?Y?`PG^4"((_@%-!-X@,PDN<&8(_@`%"@
MX08`H.$($(WB`#"3Y0PPC>4`,*#CROK_ZP!`4.("```*`##4Y0``4^,.```:
ML""?Y:@PG^4"((_@`S"2YP`@D^4,,)WE`B`SX``PH.,@```:!1"@X8P`G^4`
M`(_@%-"-XO!`O>A[^__J!0"@X73Y_^L`<*#A!`"@X7'Y_^L``(?@`@"`XOSX
M_^M<,)_E7!"?Y04@H.$#,(_@`1"/X`!`C>4`0*#A7?G_ZT0@G^4L,)_E`B"/
MX`,PDN<`()/E##"=Y0(@,^``,*#C!!"@`08`H`'A__\*7?G_Z_QQ``"\'```
M(`$``+1Q``!<'```,!L``#`;```X<0```<J@X_!/+>D,P$W@P`Z,Y4??3>+(
MH(WB"N"@X0`6G^4`QI_E`":?Y0$0C^`"()'G#,"/X`PPC.(8D(SBL%"-X@`@
MDN44(8WE`""@XP!PH.$'`)/H!P"%Z`\`N>@/`*[H`P"9Z##`C.*\0(WB`P".
MZ`<`G.@'`(3HL`6?Y1A@C>(&$*#A``"/X&_Z_^N@A9_E`)!0X@B`C^`"```*
M`##9Y0``4^,)`0`:+?G_Z][X_^L``%#C<@``"@"0D.4``%GC;P``"@D`H.$?
M^?_K@`"@X0$`@.*J^/_K`"#9Y0!`H.$``%+C%`"-Y0@```I$M9_E"["/X`0`
MH.$+$*#A"?G_ZP$@^>4"0(3B``!2X_C__QHD!9_E``"/X`(``.H$`+KE``!0
MXPT```H&$*#A1OK_ZP!`4.+X__\*`##4Y0``4^/U__\*>OK_ZP``4./R__\*
M!`"@X9_X_^L`0%#B#```&@1`E>0``%3C"0``"@`PU.4``%/CQ0``"@0`H.%L
M^O_K``!0X_'__QH$0)7D``!4X_7__QH$`*#AZ_C_ZQ20G>4`4*#A"0"@X>?X
M_^L`4(7@`5N%X@10A>(%`*#A</C_ZP20C>4`D*#A<#2?Y7`4G^4#,(_@`#"-
MY6@TG^4$(*#A`S"/X`$0C^#.^/_K!QV@XPD`H.&\^/_K`0!PXP,``!JV^/_K
M`,"0Y1$`7..E```:!A"@X0D`H.&Y^/_K`$!0XBP```H@))_E(!2?Y0(`F.<)
M,*#A`""7Y0``D.4!$(_@D?C_ZP!0H.,$))_EV#.?Y0(@C^`#,)+G`""3Y10Q
MG>4"(#/@`#"@X^D``!H%`*#A1]^-XO"/O>A6^/_K`)!0XH0``!H$`)3D``!0
MXPD```H&$*#A[/G_ZP`P4.+X__\*`##3Y0``4^/R__\:!`"4Y```4./U__\:
M#0"@XS#X_^N0DY_E4R"@XP!`H.$)D(_@%`"-Y83__^HH,)WE#SH#X@$)4^/.
M__\:,*"=Y9SX_^L``%KARO__&B@PG>6#.Z#AHSN@X0<-4^/%__\:!0"@X1OX
M_^L`4*#A/`.?Y080H.$``(_@R/G_ZP`04.)U```*``"7Y;C[_^L`H%#B<0``
M"@H`H.&`^/_K`P!0XP"`H.$,``":!!.?Y00`0.(``(K@`1"/X/3W_^L``%#C
M!0``&@0`6..7```*"("*X`4P6.4O`%/CDP``"M0"G^4&$*#A``"/X*SY_^L`
M`%#C`P``"@`PT.4P`%/C``!3$P0``!H`$*#C"@"@X0GX_^L`8%#B4@``&IP2
MG^6<`I_E`1"/X```C^!A^O_KU/?_ZXPBG^6,,I_EC!*?Y0(@C^"(@I_EB'*?
MY8ABG^4%`(WH`S"/X`D@H.$%`*#A`1"/X$7X_^L(@(_@!W"/X`9@C^`-``#J
M+OC_ZP`PD.41`%/C#@``&K[W_^L`P*#A`4"$X@@PH.$)(*#A!Q"@X04`H.%0
M`(WI`,"-Y3/X_^L'':#C!0"@X2'X_^L!`'#C[/__"@D`H.$@^/_K#`*?Y040
MH.$``(_@-OK_ZP4`H.&2_O_K;?__Z@-`H.$^___J*_C_ZX``H.$!`(#B"O__
MZIPAG^78$9_E`@"8YPDPH.$`()?E`1"/X`#`C>4``)#E[_?_ZUS__^J`_O_K
MM"&?Y4PQG^4"((_@`S"2YP`@D^44,9WE`B`SX``PH.-&```:"0"@X4??C>+P
M3[WHL_?_Z@"@E^6+___J]OW_ZP"`4>(`<*#AJ/__N@"@H.,*(%#B`##(X@8`
MH.$`H(WEX+"-XGGW_^L&(*#C"Q"@X08`H.'8]__K!@!0XS```!HX,9_EX""=
MY0,`4N&7__\:M"#;X2@QG^4#`%+AD___&C(@5^(`,,CB!@"@X0"@C>7H0(WB
M9??_ZR@@H.,&`*#A!!"@X<3W_^LH`%#C'```&O`@G^7P,)_E\!"?Y0(@C^`$
M((WE!0"@X0D@H.$`0(WE`S"/X`$0C^`0H<WEU/?_ZZ3__^H$<)?E``!7XVC_
M_PH'`*#AU_?_ZP,`4.-D__^:K!"?Y00`0.(``(?@`1"/X$SW_^L``%#C!Z"@
M`5S__^K/]__KC`"?Y0``C^"6_?_KR'````!R```@`0``+!H``%QP``#D&@``
M6!H``!@:``#X&0``^!@``/P```#P&0``H&X````9``!@&0``*!D``)`7``#0
M%P``4!<``(09``#<%@``K!@``,@6``"P&```5!D``#06```T%P``%&P```!#
M04-(10``O!<``!05``#<%@``D!8``'P6```!RJ#C\$`MZ0S`3>#@#XSEC"*?
MY8PRG^4"((_@`S"2YPS03>(`,)/E!#"-Y0`PH.-P3QWN#6"@X6PRG^5L`I_E
M`S"?YP80H.$#4)3G``"/X&0PU>5E,,7ES_C_ZP``4.,"```*`##0Y3$`4^-B
M```*W?O_ZS@RG^4#,)_G`U"4YS`2G^4%`*#A`S"@XP$@H.,!$(_@+_?_ZP!0
M4.(,```*#""5Y1`RG^4`$)+E`S"?YP@BG^4#`)3G`B"/X"OW_^L,,)7E`!"3
MY0@PD>4!!1/C6@``&N@1G^4#,*#C`1"?YP$@H.,!`)3GV!&?Y0$0C^`8]__K
M`%!0X@L```K(`9_E!A"@X0``C^"C^/_K`"!0XCT```JT,9_E#!"5Y0,PG^<`
M$)'E`P"4YQ#W_^N@,9_EH!&?Y0,PG^<!(*#C`U"4YP$0C^`%`*#AM_;_ZX@A
MG^4`$*#A`B"/X`4`H.$#]__K`""@XW0QG^5T`9_E`S"?YP80H.$#,)3G``"/
MX&4@P^6%^/_K7$&?Y0``4.,$0(_@"`"$Y1````H'':#C)O?_ZP$P@.(1`%#C
M`0!3$S0``(HT(9_E[#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XRH``!H,
MT(WB\("]Z`0`E.7:_?_K``!0XP@`A.7I__\:^`"?Y0``C^"7]O_K`3#0Y0``
M4^.=__\*F/__ZOGY_^L`<%#B#@``"M0PG^4,()7E`S"?YP`0DN4#`)3G!R"@
MX<[V_^L'`*#A`O?_Z[K__^JP,)_E`S"?YP,`E.>:]O_KG___ZJ`@G^6@,)_E
M`B"/X`P0E>4#,)_G!""2Y0`0D>4`()+E`P"4Y[SV_^NJ___J"/?_ZW@@G^4`
M,*#A=`"?Y0(@C^`&`)+I``"/X``0D>5M]O_K*&H``"`!```4:P``"!0``-QJ
M``"8%0``J&H``'05``!X:@``2!4```@3```X:@``(&H``/@4``#\%```Z&D`
M`(@2``!0:@``B&@``&04```T:0``$&D``(!I``#P:```3&D``.03```!RJ#C
M,$`MZ0S`3>#H#XSE#"&?Y0PQG^4"((_@`$"@X00!G^4#,)+G#-!-X@T0H.$`
M`(_@`#"3Y00PC>4`,*#C$OC_ZP`P4.(*```*`##3Y0``4^,P`%,3`3"@`P`P
MH!,!,"/B``!4XP`PH`,!,`,2``!3XPH``!JP()_EI#"?Y0(@C^`#,)+G`""3
MY00PG>4"(#/@`#"@XR```!H,T(WB,("]Z``PU.4``%/C\?__"@0`H.&>^O_K
M+Q"@XP!0H.%,]O_K``!0XP%0@!(%`*#A4?;_ZU@0G^4$(*#C`1"/X#[V_^L`
M`%#CXO__&D0@G^4P,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C`P``&@0`
MH.$,T(WB,$"]Z$'X_^J=]O_K'&<``"`!```T$0``M&8``%`1``!`9@``````
M``'*H./P3RWI#,!-X)`.C.58*Y_E6#N?Y0(@C^`#,)+G4]]-X@`PD^5$,8WE
M`#"@XPT0H.$`<*#A'""`XEP`@.($,)+D,S^_Y@``4N$$,*'E^O__&C@`G>4\
MX)WE0#"=Y03`G>4(4)WE"""-XD)OC>(```#J`5"@X0-`H.$<,)+E!!"RY0$P
M(^``,"/@##`CX.,_H.$"`%;A#@"@X07`H.$$X*#A.#""Y?'__QK$.I_E#%"7
MY000G>400)?E`1"7Z0#@E^4%("S@`Q"!X`00@>``(`+@!2`BX`A@G>7N'8'@
M`A"!X&`A+.`#8(;@#B`"X`5@AN`,("+@;I&@X08@@N`,8)WE8($IX`-@AN`!
M@`C@#&"&X!2PG>5@@2C@X2V"X!"@G>4&@(C@86$IX.*-B.`"8`;@`["+X&(A
MH.$)L(O@`Z"*X`E@)N!AD2+@8*&*X`B0">`*8(;@89$IX!B@G>7H;8;@"Y")
MX&BQ(N`#H(K@!K`+X.:=B>!AH8K@9A&@X0)@*^`*8(;@'*"=Y6BQ(>`#H(K@
M`B"*X""@G>4)L`O@`Z"*X.EMAN!HH8K@:($KX&FQ(>`"@(C@!K`+X.:-B.!F
M(:#A`6`KX`I@AN`DH)WE:;$BX`.@BN`!$(K@**"=Y0BP"^`#H(K@::&*X&F1
M*^#H;8;@`9")X&@1(N`&$`'@`A`AX`H0@>`LH)WEYIV)X`.@BN!F8:#A`B"*
MX#"@G>5HL2;@";`+X`.@BN!HH8K@:($KX.D=@>`"@(C@:2$FX`$@`N`&("+@
M"B""X#2@G>7AC8C@`Z"*X&$1H.$&8(K@::$AX`B@"N`XL)WE::$JX.@M@N`&
MH(K@:&$AX`.PB^`"8`;@:;&+X`%@)N`+8(;@/+"=Y>*MBN`#L(O@8B&@X0&P
MB^!`$)WE:)$BX`,0@>`*D`G@ZFV&X&@1@>!HD2G@:H$BX`:`".`"@"C@`8"(
MX$00G>4+D(G@YIV)X`,0@>!F8:#A2+"=Y0(@@>!J$2;@`["+X`D0`>!JL8O@
M:A$AX$R@G>7IC8C@`A"!X&DA)N`#H(K@""`"X`8@(N`&8(K@4*"=Y>@=@>!H
M@:#A`S"*X&FA*.`!H`K@"R""X&FA*N#A+8+@!J"*X&%A*.`"8`;@:3&#X`A@
M)N!8L)WE`V"&X!0XG^54D)WEXJV*X`.PB^!B(:#A`Y")X&&QB^!A$2+@"A`A
MX`B`B>#J;8;@`8"(X.:=B.!<@)WE`X"(X`*`B.!J(2+@!B`BX`(0B^!@()WE
M9F&@X0,@@N!J(8+@:J$FX`F@*N`*@(C@9*"=Y>D=@>`#H(K@!J"*X&EA)N`!
M8";@X8V(X`8@@N#H;8+@:""=Y6$1H.$#((+@:2&"X&F1(>`(D"G@"9"*X&R@
MG>7FG8G@`Z"*X`&@BN!H$2'@!A`AX`$@@N#I'8+@<""=Y69AH.$#((+@:"&"
MX&B!)N`)@"C@"("*X'2@G>7AC8C@`Z"*X`:@BN!I82;@`6`FX`8@@N#H;8+@
M>""=Y6$1H.$#((+@:2&"X&F1(>`(D"G@"9"*X'R@G>7FG8G@`Z"*X`&@BN!H
M$2'@!A`AX`$@@N#I'8+@@""=Y69AH.$#((+@:"&"X&B!)N`)@"C@"("*X(2@
MG>7AC8C@`Z"*X`:@BN!I82;@`6`FX`8@@N#H;8+@8;&@X8@@G>5I$2O@"!`A
MX`,@@N!I(8+@`9"*X&BA*^`&H"K@YIV)X`H@@N#IK8+@D""=Y8P0G>5F8:#A
M`R""X`,0@>!H(8+@:($FX`F`*.`+$('@"!"!X.J-@>"4$)WEI+"=Y0,0@>`&
M$('@:6$FX`I@)N`&((+@Z&V"X)@@G>5JH:#A`R""X&DA@N!ID2K@")`IX`D0
M@>"<D)WEYAV!X`.0B>`*D(G@:*$JX`:@*N`*((+@H*"=Y69AH.$#,(K@:#&#
MX&B!)N`!@"C@X2V"X`B`B>!AD2;@`I`IX.*-B.`),(/@Z)V#X+0UG^6HH)WE
M8B&@X0.PB^`&L(O@`Z"*X&%A@N%AH8K@"&`&X&$1`N`!$(;A"Q"!X&BQ@N'I
M'8'@:6&@X0FP"^!HD0+@"9"+X:RPG>4*D(G@L*"=Y0.PB^`"L(O@`Z"*X&@A
MAN%HH8K@`2`"X&B!!N#AG8G@""""X6&!AN$+((+@"8`(X&&Q!N`+@(CAM+"=
MY>DM@N`#L(O@!K"+X+A@G>5ID:#A"H"(X`-@AN!AH8GA`J`*X&%AAN!A$0G@
MXHV(X`$0BN%BH8GA"Q"!X`B@"N!BL0G@"Z"*X;RPG>7H'8'@`["+X`FPB^#`
MD)WE:(&@X09@BN`#D(G@8J&(X0&@"N!BD8G@8B$(X.%MAN`"((KA8:&(X0L@
M@N`&H`K@8;$(X`N@BN'$L)WEYBV"X`.PB^`(L(O@R("=Y69AH.$)D(K@`X"(
MX&&AAN$"H`K@88&(X&$1!N#BG8G@`1"*X6*AAN$+$('@":`*X&*Q!N`+H(KA
MS+"=Y>D=@>`#L(O@!K"+X-!@G>5ID:#A"("*X`-@AN!BH8GA`:`*X&)AAN!B
M(0G@X8V(X`(@BN%AH8GA"R""X`B@"N!AL0G@"Z"*X=2PG>7H+8+@`["+X`FP
MB^#8D)WE:(&@X09@BN`#D(G@8:&(X0*@"N!AD8G@81$(X.)MAN`!$(KA8J&(
MX0L0@>`&H`K@8K$(X`N@BN'<L)WE"9"*X."@G>7F'8'@`["+X&9AH.$(L(O@
M`Z"*X&*!AN%BH8K@`8`(X&(A!N#AG8G@`H"(X6$AAN$+@(C@"2`"X&&Q!N`+
M((+AY+"=Y0H@@N#HH)WEZ8V(X`.PB^!ID:#A!K"+X`.@BN!A88GA8:&*X`A@
M!N!A$0G@Z"V"X`%@AN%H$8GA"V"&X`(0`>!HL0G@"Q"!X>RPG>4*$('@\*"=
MY>)MAN`#L(O@8B&@X0FPB^`#H(K@:)&"X6BABN`&D`G@:($"X.@RG^4(D(GA
M]("=Y>8=@>`+D(G@`X"(X&:Q@N$!L`O@`H"(X&8A`N`"((OA"B""X/B@G>7A
MG8G@`Z"*X&$1H.%FH8K@9F$AX`E@)N`&@(C@_&"=Y0"QG>4#8(;@Z2V"X`%@
MAN!I$2'@XHV(X`(0(>`#L(O@8B&@X0$0BN!IL8O@!*&=Y6F1(N`(D"G@"6"&
MX`.@BN`(D9WEZ!V!X`*@BN!H(2+@X6V&X`$@(N`#D(G@81&@X6B1B>!H@2'@
M!H`HX`B`BN`,H9WE`B"+X`.@BN#F+8+@`:"*X&81(>`"$"'@`1")X!"1G>7B
MC8C@`Y")X&(AH.%FD8G@9F$BX`A@)N`&8(K@%*&=Y>@=@>`#H(K@`J"*X&@A
M(N`!("+@`B")X!B1G>7A;8;@`Y")X&$1H.%HD8G@:($AX`:`*.`(@(K@'*&=
MY>8M@N`#H(K@`:"*X&81(>`"$"'@`1")X""1G>7BC8C@`Y")X&(AH.%FD8G@
M9F$BX`A@)N`&8(K@)*&=Y>@=@>`#H(K@`J"*X&@A(N`!("+@`B")X"B1G>7A
M;8;@`Y")X&$1H.%HD8G@:($AX`:`*.`(@(K@+*&=Y>8M@N`#H(K@`:"*X&81
M(>`"$"'@`1")X#"1G>7BC8C@`Y")X&(AH.%FD8G@9F$BX`A@)N`&8(K@-*&=
MY>@=@>`#H(K@`J"*X&@A(N`!("+@`B")X#B1G>7A;8;@`Y")X&$1H.%HD8G@
M:($AX`:`*.#F+8+@"("*X.*-B.!H487@#%"'Y3Q1G>4#4(7@`5"%X&81(>`"
M$"'@`1")X.@=@>!AP8S@","'Y4#!G>5B(:#A`S",X&;!(N`"0(3@#C"#X`C`
M+.!H(2+@`2`BX&8Q@^`,4(7@X1V%X`(P@^#A/8/@4""?Y0`PA^4!`(#@,#"?
MY0(@C^`00(?E!`"'Y0,PDN<`()/E1#&=Y0(@,^``,*#C`0``&E/?C>+PC[WH
MNO/_Z]QE```@`0``F7F"6J'KV6[<O!N/UL%BRK1:```!RJ#C$$`MZ0S`3>#X
M#XSE8`"@XSCS_^L`(*#C#'N?[33`G^4T$)_E-$"?Y33@G^4$>X#M"$"`Y0S@
M@.4`P(#E!!"`Y1@@@.5<((#E$("]Z`#P(./PX=+#``````$C16>)J\WO_MRZ
MF'94,A`!RJ#C\$<MZ0S`3>#@#XSE`E"@X0"`H.$4,)#E@B&@X0(PD^`8()#E
M%#"`Y5P`D.4!(((BI2Z"X```4.,!H*#A&""(Y1QPB`(6```*0$!@XAQPB.(%
M`%3A``"'X`5`H*$!`%#A0@``*@0P@.`#`%'A!&"!(#D``#H*$*#A!""@X6[S
M_^M<,)CE`S"$X$``4^-<,(CE\(>]&`@`H.'9_/_K!J"@X0101>`_`%7C&P``
MV@I`H.%<D(CB0&"*X@0`5^$B```J"0!4X20``#H&H*#A!S"@X4#@A.(`P)3E
M!`"4Y0@0E.4,()3E$$"$X@X`5.$`P(/E!`"#Y0@0@^4,((/E$#"#XO/__QH(
M`*#A0%!%XKS\_^L_`%7C0&"&XN;__\H*`%?A#@``.@(``)H%,(K@`P!7X0D`
M`#H%(*#A"A"@X0<`H.$]\__K7%"(Y?"'O>@&H*#AW?__F@8`5^';__\J\`#P
MYP4PA^`#`%KA\?__*OK__^H$8('@OO__F@8`4.&\__\J]?__Z@'*H./P02WI
M#,!-X.@/C.5_(.#C%#"1Y1A@D>4S?[_FHS&@X3\P`^(!P(/B'("!XC@`7.,!
M0*#A`%"@X39OO^8#(,CG/```V@`0H.-`(&SB#`"(X*+R_^L$`*#AA_S_ZS@@
MH.,`$*#C"`"@X9SR_^L$`*#A]&7$X8#\_^L#,-3E!`"@X0`PQ>6R,-3A`3#%
MY0`PE.4C-*#A`C#%Y0`PE.4#,,7E!S#4Y00PQ>6V,-3A!3#%Y00PE.4C-*#A
M!C#%Y00PE.4',,7E"S#4Y0@PQ>6Z,-3A"3#%Y0@PE.4C-*#A"C#%Y0@PE.4+
M,,7E#S#4Y0PPQ>6^,-3A#3#%Y0PPE.4C-*#A#C#%Y0PPE.4/,,7E$S#4Y1`P
MQ>6R,=3A$3#%Y1`PE.4C-*#A$C#%Y1`PE.43,,7E\$&]Z,_R_^H`$*#C#`"(
MX#@@;.)E\O_KQ___Z@%`+>D!0+WH'O\OX3X```!!````#````$$````1````
M00```"<```!!````-@```$$````#````00````8```!!````%0```$$````/
M````00````X```!!````)@```$$````3````00```"D```!!`````@```$$`
M```9````00````H```!!````"P```$$``````````````"5S+R5S````1'EN
M84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4
M`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!23T=.
M04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"`%!%
M4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'3$]"
M04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`````Q````;'-E96L@
M9F%I;&5D`````')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T`
M`"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(````
M`'!A<FP`````+G!A<@````!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`
M````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#8S````56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@`````M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!4
M35``+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[
M,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL
M"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S
M971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@
M<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#
M(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D
M9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D
M<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A
M(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*
M<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D
M8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]
M"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R
M7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M
M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD
M("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R
M(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`[
M"F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@
M/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D
M9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/
M5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*
M7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO
M(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU3
M5VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E
M=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE
M(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!]
M(#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T
M7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O
M9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N
M86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%
M<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A
M<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;
M0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@
M;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@
M*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U
M=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U
M=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@
M)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH
M(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@
M:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U
M9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I
M<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B
M)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>
M*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE
M+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M
M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R
M8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK
M*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D
M=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D
M;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I
M;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S
M879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF
M;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D
M(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@
M8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE0
M7TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C
M=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S
M=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S
M=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE
M+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2
M155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R
M;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@
M(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A
M<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'
M5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I
M9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G
M*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD
M8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@
M/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L
M("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*
M?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI
M9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L
M971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2
M.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]
M"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY
M("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B
M.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R
M;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A
M<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M
M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK
M*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@
M)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B
M)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q
M<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("10
M2UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B
M.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO
M861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR
M96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E
M;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF
M("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\
M7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F
M:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A
M9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!
M4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@
M(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@
M<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@
M9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)
M3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@
M("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL
M92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K
M97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];
M7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64[
M"FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I
M;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I
M;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F
M:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R
M(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\
M)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C
M:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A
M8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T[
M"F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@
M>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@
M(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT
M*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M
M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L
M(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C
M86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C
M:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(
M12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#
M*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R
M(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE
M*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z
M.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@
M<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%
M>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL
M:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD
M"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&
M:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N
M86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU
M;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E
M<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M
M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA
M;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B
M)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E
M;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*
M9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@
M+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60[
M"F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C
M:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@
M)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER
M(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@
M)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D
M(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI
M(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?
M<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F
M:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S
M:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P
M.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S
M+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@
M)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES
M>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@
M)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B
M.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U
M;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP
M;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H
M;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE
M*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*
M?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M
M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M
M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[
M7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES
M=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T[
M"B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T
M*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB
M.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]
M"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L
M:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?
M<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$
M?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF
M;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!
M4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E
M;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P``
M``!#04-(10``/@```$$````,````00```!$```!!````)P```$$````V````
M00````,```!!````!@```$$````5````00````\```!!````#@```$$````F
M````00```!,```!!````*0```$$````"````00```!D```!!````"@```$$`
M```+````00``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````P!<``"@7```!````%@,`
M``$````A`P``'0```'4$```,````6!````T```"81P``&0```,R=```;````
M!````!H```#0G0``'`````0```#U_O]O<`$```4```#\"```!@```%P"```*
M````DP0```L````0````%0`````````#````Q)X```(```#8`0``%````!$`
M```7````@`X``!$```"0#0``$@```/`````3````"````!X````(````^___
M;P$```CZ__]O$```````````````````````````````````````````````
M``````````#4G0````````````!D$```9!```&00``!D$```9!```&00``!D
M$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00
M``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```9!``
M`&00``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```
M9!```&00``!D$```9!```&00``!D$```9!```&00``!D$```9!```&00``!D
M$```9!```&00``!D$```9!```&00``!D$```9!```$`3`````````````)A'
M`````````````%@0````````````````````````````````````````````
M`````````````*````I005(N<&T*`````&Q+``"`2````````$!)``!$20``
M8$L``(A(``!H2P```````$Q+``!42P```````'1+``!'0T,Z("A!;'!I;F4@
M,3,N,BXQ7V=I=#(P,C0P,S`Y*2`Q,RXR+C$@,C`R-#`S,#D`03(```!A96%B
M:0`!*`````4V2UH`!@<(`0D!"@(2!!,!%`$5`1<#&`$:`AP!'@(B`40!`"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M``````L````!`````@```#0!```T`0``&````````````````0`````````3
M````!P````(```!,`0``3`$``"0```````````````0`````````)@```/;_
M_V\"````<`$``'`!``#L````!``````````$````!````#`````+`````@``
M`%P"``!<`@``H`8```4````#````!````!`````X`````P````(```#\"```
M_`@``),$``````````````$`````````0`````D````"````D`T``)`-``#P
M````!``````````$````"````$D````)````0@```(`.``"`#@``V`$```0`
M```1````!`````@```!2`````0````8```!8$```6!````P`````````````
M``0`````````30````$````&````9!```&00``#8`@`````````````$````
M!````%@````!````!@```$`3``!`$P``6#0`````````````"`````````!>
M`````0````8```"81P``F$<```P```````````````0`````````9`````$`
M```"````I$<``*1'``#D00`````````````$`````````&P````!`````@``
M`(B)``"(B0``!```````````````!`````````!V````#@````,```#,G0``
MS(T```0```````````````0````$````@@````\````#````T)T``-"-```$
M```````````````$````!````(X````&`````P```-2=``#4C0``\`````4`
M````````!`````@```"7`````0````,```#$G@``Q(X``#P!````````````
M``0````$````G`````$````#`````*````"0``!$```````````````$````
M`````*(````(`````P```$2@``!$D```+```````````````!`````````"G
M`````0```#``````````1)```#$```````````````$````!````L`````,`
M`'```````````'60```S```````````````!``````````$````#````````
=``````"HD```P````````````````0``````````
